@@ -226,7 +226,7 @@ function PrintPreviewImpl(guiAction) {
     this.optOutRelativeZeroResume = true;
 }
 
-PrintPreviewImpl.prototype = NewFile.getDefaultAction(false);
+PrintPreviewImpl.prototype = NewFile.getDefaultAction(false, true);
 PrintPreviewImpl.includeBasePath = includeBasePath;
 
 PrintPreviewImpl.State = {
@@ -473,6 +473,13 @@ PrintPreviewImpl.prototype.mouseMoveEvent = function(event) {
     }
 };
 
+PrintPreviewImpl.showPageSettings = function() {
+    var action = RGuiAction.getByScriptFile("scripts/Edit/DrawingPreferences/DrawingPreferences.js");
+    var appWin = EAction.getMainWindow();
+    appWin.setProperty("PreferencesPage", "PageSettings");
+    action.trigger();
+};
+
 /**
  * Reimplementation from EAction. Implements initialization of options
  * toolbar from member variables.
@@ -512,7 +519,24 @@ PrintPreviewImpl.prototype.showUiOptions = function(resume) {
     scaleCombo.blockSignals(false);
 
     var action = RGuiAction.getByScriptFile("scripts/Edit/DrawingPreferences/DrawingPreferences.js");
-    widgets["ShowMoreOptions"].setDefaultAction(action);
+    //widgets["ShowMoreOptions"].setDefaultAction(action);
+    if (isFunction(widgets["ShowMoreOptions"].setIcon)) {
+        widgets["ShowMoreOptions"].setIcon(new QIcon(autoPath("scripts/Edit/DrawingPreferences/DrawingPreferences.svg")));
+    }
+    else {
+        widgets["ShowMoreOptions"].icon = new QIcon(autoPath("scripts/Edit/DrawingPreferences/DrawingPreferences.svg"));
+    }
+    if (isFunction(widgets["ShowMoreOptions"].setToolTip)) {
+        widgets["ShowMoreOptions"].setToolTip(qsTr("Page Settings"));
+    }
+    else {
+        widgets["ShowMoreOptions"].toolTip = qsTr("Page Settings");
+    }
+    try {
+        widgets["ShowMoreOptions"].clicked.disconnect(PrintPreviewImpl.showPageSettings);
+    }
+    catch (e) {}
+    widgets["ShowMoreOptions"].clicked.connect(PrintPreviewImpl.showPageSettings);
 
     switch(Print.getColorMode(document)) {
     case RGraphicsView.FullColor:
@@ -1051,7 +1075,7 @@ PrintPreviewImpl.prototype.getPaperBox = function() {
 PrintPreviewImpl.prototype.slotAutoZoomToPage = function() {
     if (!isNull(this.view)) {
         var pBox = this.getPaperBox();
-        this.view.zoomTo(pBox, 10);
+        this.view.zoomTo(pBox, 50);
     }
 };
 
