@@ -6,7 +6,17 @@ var credits =
                               ],
         [ "Christian Aigner", "Misc > Draw > Dovetail from 2 Points<br>"
                               ],
-        [ "CVH",              "Misc > Script Examples > Mathematics > FlexPainter<br>"
+        [ "CVH",              "Misc > Script Examples > Mathematics > FlexPainter<br>" +
+                              "Misc > Import/Export > Draw from CSV<br>" +
+                              "Misc > Information > Area Centroid<br>" +
+                              "Misc > Information > Wire Centroid<br>" +
+                              "Misc > Information > Sum Centroids Weighted<br>"
+                              ],
+        [ "Dmitry Ponomarev", "Misc > Import/Export > Batch2Pdf visible layout blocks<br>" +
+                              "Misc > Draw > Text Aligned Leader<br>" +
+                              "Misc > Draw > Leader from Selected Text<br>"
+                              ],
+        [ "gmpowell71",       "Misc > Information > Bearing / Azimuth<br>"
                               ],
         [ "Matfie",           "Gear generator library item \"InvoluteSpur\"<br>"
                               ],
@@ -19,6 +29,8 @@ var credits =
                               ],
         [ "Norbert K.",       "Modify > Break out Gap<br>"
                               ],
+        [ "Pete Vickerstaff", "Misc > Draw > Polyline break symbol from 2 points<br>"
+                              ],
         [ "Robert S.",        "Direct distance entry<br>" +
                               "Selecting overlapping entities<br>" +
                               "Polyline area calculation<br>" +
@@ -44,7 +56,7 @@ var credits =
                               "Info > Arc/Circle/Ellipse Area<br>" +
                               "Custom linetype support, loading .lin files<br>"
                               ],
-        [ "Stephen Casner",   "Misc > Select > By Color"
+        [ "Stephen Casner",   "Misc > Select > By Color<br>"
                               ],
         [ "Tamas Tevesz",     "Port to FreeBSD<br>" +
                               "Various improvements and fixes<br>"
@@ -84,6 +96,10 @@ var credits =
                                  "XMASTREE-01, XMASTREE-02"
                                  ],
     ],
+    [
+        qsTr("Themes"),
+        [ "Pete Vickerstaff",    "Coffee, Cyan, Dark Grey, Default Plus, Forest, Heather, Light Grey, Midnight, Pastel, Pink Champagne" ],
+    ],
     [
         qsTr("Translations"),
         [ "Petr Zgraja, 'fialot'", "Czech (cs) translation" ],
